@@ -182,6 +182,7 @@ def save_dataset_local(
         # task_folder = os.path.join("/shared", job_id, task_id)
         workflow_id = exp_engine_metadata["wf_id"]
         task_name = variables.get("task_name")
+        # task_name = variables.get("PA_TASK_NAME")
         task_folder = os.path.join("/shared", workflow_id, task_name)
         os.makedirs(task_folder, exist_ok=True)
         output_file_path = os.path.join(task_folder, key)
@@ -357,22 +358,29 @@ def load_dataset_local(variables: Dict[str, Any], key: str) -> Any:
     print(f"Loading input data with key '{key}'")
 
     # Validate required keys
-    validate_variables_has_key(variables, "PA_JOB_ID", "variables")
-    validate_variables_has_key(variables, "PA_TASK_NAME", "variables")
+    # validate_variables_has_key(variables, "PA_JOB_ID", "variables")
+    # validate_variables_has_key(variables, "PA_TASK_NAME", "variables")
+    validate_variables_has_key(variables, "task_name", "variables")
 
     if key in variables:
         input_filename = variables.get(key)
         print(f"Loading external input data from {input_filename}")
         return load_dataset_by_path(input_filename)
     else:
-        job_id = variables.get("PA_JOB_ID")
-        task_id = variables.get("PREVIOUS_TASK_ID")
-        task_folder = os.path.join("/shared", job_id, task_id)
-        task_name = variables.get("PA_TASK_NAME")
+        # job_id = variables.get("PA_JOB_ID")
+        # task_id = variables.get("PREVIOUS_TASK_ID")
+        # task_folder = os.path.join("/shared", job_id, task_id)
+        # task_name = variables.get("PA_TASK_NAME")
+        task_name = variables.get("task_name")
+        workflow_id = exp_engine_metadata["wf_id"]
         if task_name in execution_engine_mapping:
-            if key in execution_engine_mapping[task_name]:
-                key = execution_engine_mapping[task_name][key]
-        input_filename = os.path.join(task_folder, key)
+            inputs = execution_engine_mapping[task_name]
+            output_name = inputs["file_name"]
+            source_task = inputs["source_task"]
+            # if key in execution_engine_mapping[task_name]:
+            #     key = execution_engine_mapping[task_name][key]
+        task_folder = os.path.join("/shared", workflow_id, source_task)
+        input_filename = os.path.join(task_folder, output_name)
         print(f"Loading intermediate input data from {input_filename}")
         return load_pickled_dataset_by_path(input_filename)
 
